@@ -6,12 +6,12 @@ def show_options(input: str, options: List):
 
 
 def default_radius(bbox, ratio=0.1):
-    w, h = (bbox[2] - bbox[0]), (bbox[3] - bbox[1])
+    w, h = abs(bbox[2] - bbox[0]), abs(bbox[3] - bbox[1])
     r = min([w, h]) * ratio
     return r
 
 
 def default_radius_3d(bbox, ratio=0.1):
-    w, h, d = (bbox[3] - bbox[0]), (bbox[4] - bbox[1]), (bbox[5] - bbox[2])
+    w, h, d = abs(bbox[3] - bbox[0]), abs(bbox[4] - bbox[1]), abs(bbox[5] - bbox[2])
     r = min([w, h, d]) * ratio
     return r
